Description Usage Arguments Value See Also Examples
Fits by ML method the unit level model of Lyu, Berg and Hofmann. The specified link function is used in the binary part.
1 | mleLBH(data_2p, link = "logit")
|
data_2p |
a two-part data object returned by |
link |
a specification for the link function used to model the binary part.
The accepted link functions are |
The function returns a list with the following objects:
fixed: list with the estimated values of the fixed regression coefficient
in the positive part (p1) and in the binary part (p0).
random: data frame with the predicted random effects in the positive part (p1)
and the binary part (p0).
errorvar: estimated model error variance in the positive part.
refvar1: estimated random effects variance in the positive part.
refvar0: estimated random effects variance in the binary part.
refcor: estimated correlation coefficient of the random effects between the two parts.
loglik: log-likelihood accomodating a general transformation family and lambda
in the positive part as specified in as.2pdata.
residuals: the marginal (mar) and conditional (con) residuals
from the model fit in the positive part (p1, cases with nonpositive response are NA.).
fit0: model parameter estimator under independence assumption.
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.